# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_volume_format import AudioVolumeFormat
from bitmovin_api_sdk.models.audio_volume_unit import AudioVolumeUnit
from bitmovin_api_sdk.models.filter import Filter
import pprint
import six


class AudioVolumeFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 volume=None,
                 unit=None,
                 format_=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, float, AudioVolumeUnit, AudioVolumeFormat) -> None
        super(AudioVolumeFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._volume = None
        self._unit = None
        self._format = None
        self.discriminator = None

        if volume is not None:
            self.volume = volume
        if unit is not None:
            self.unit = unit
        if format_ is not None:
            self.format = format_

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AudioVolumeFilter, self), 'openapi_types'):
            types = getattr(super(AudioVolumeFilter, self), 'openapi_types')

        types.update({
            'volume': 'float',
            'unit': 'AudioVolumeUnit',
            'format': 'AudioVolumeFormat'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AudioVolumeFilter, self), 'attribute_map'):
            attributes = getattr(super(AudioVolumeFilter, self), 'attribute_map')

        attributes.update({
            'volume': 'volume',
            'unit': 'unit',
            'format': 'format'
        })
        return attributes

    @property
    def volume(self):
        # type: () -> float
        """Gets the volume of this AudioVolumeFilter.

        Audio volume value (required)

        :return: The volume of this AudioVolumeFilter.
        :rtype: float
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        # type: (float) -> None
        """Sets the volume of this AudioVolumeFilter.

        Audio volume value (required)

        :param volume: The volume of this AudioVolumeFilter.
        :type: float
        """

        if volume is not None:
            if not isinstance(volume, (float, int)):
                raise TypeError("Invalid type for `volume`, type has to be `float`")

        self._volume = volume

    @property
    def unit(self):
        # type: () -> AudioVolumeUnit
        """Gets the unit of this AudioVolumeFilter.


        :return: The unit of this AudioVolumeFilter.
        :rtype: AudioVolumeUnit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        # type: (AudioVolumeUnit) -> None
        """Sets the unit of this AudioVolumeFilter.


        :param unit: The unit of this AudioVolumeFilter.
        :type: AudioVolumeUnit
        """

        if unit is not None:
            if not isinstance(unit, AudioVolumeUnit):
                raise TypeError("Invalid type for `unit`, type has to be `AudioVolumeUnit`")

        self._unit = unit

    @property
    def format(self):
        # type: () -> AudioVolumeFormat
        """Gets the format of this AudioVolumeFilter.


        :return: The format of this AudioVolumeFilter.
        :rtype: AudioVolumeFormat
        """
        return self._format

    @format.setter
    def format(self, format_):
        # type: (AudioVolumeFormat) -> None
        """Sets the format of this AudioVolumeFilter.


        :param format_: The format of this AudioVolumeFilter.
        :type: AudioVolumeFormat
        """

        if format_ is not None:
            if not isinstance(format_, AudioVolumeFormat):
                raise TypeError("Invalid type for `format`, type has to be `AudioVolumeFormat`")

        self._format = format_

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AudioVolumeFilter, self), "to_dict"):
            result = super(AudioVolumeFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioVolumeFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptationsets_api import AdaptationsetsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.subtitle.subtitle_api import SubtitleApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.image.image_api import ImageApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptation_set_list_query_params import AdaptationSetListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.progressive_muxing_information import ProgressiveMuxingInformation
import pprint
import six


class ProgressiveTsMuxingInformation(ProgressiveMuxingInformation):
    @poscheck_model
    def __init__(self,
                 mime_type=None,
                 file_size=None,
                 container_format=None,
                 container_bitrate=None,
                 duration=None,
                 video_tracks=None,
                 audio_tracks=None,
                 byte_ranges=None):
        # type: (string_types, int, string_types, int, float, list[MuxingInformationVideoTrack], list[MuxingInformationAudioTrack], list[ProgressiveTsMuxingInformationByteRanges]) -> None
        super(ProgressiveTsMuxingInformation, self).__init__(mime_type=mime_type, file_size=file_size, container_format=container_format, container_bitrate=container_bitrate, duration=duration, video_tracks=video_tracks, audio_tracks=audio_tracks)

        self._byte_ranges = list()
        self.discriminator = None

        if byte_ranges is not None:
            self.byte_ranges = byte_ranges

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ProgressiveTsMuxingInformation, self), 'openapi_types'):
            types = getattr(super(ProgressiveTsMuxingInformation, self), 'openapi_types')

        types.update({
            'byte_ranges': 'list[ProgressiveTsMuxingInformationByteRanges]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ProgressiveTsMuxingInformation, self), 'attribute_map'):
            attributes = getattr(super(ProgressiveTsMuxingInformation, self), 'attribute_map')

        attributes.update({
            'byte_ranges': 'byteRanges'
        })
        return attributes

    @property
    def byte_ranges(self):
        # type: () -> list[ProgressiveTsMuxingInformationByteRanges]
        """Gets the byte_ranges of this ProgressiveTsMuxingInformation.

        Byte ranges for the segments within the TS file

        :return: The byte_ranges of this ProgressiveTsMuxingInformation.
        :rtype: list[ProgressiveTsMuxingInformationByteRanges]
        """
        return self._byte_ranges

    @byte_ranges.setter
    def byte_ranges(self, byte_ranges):
        # type: (list) -> None
        """Sets the byte_ranges of this ProgressiveTsMuxingInformation.

        Byte ranges for the segments within the TS file

        :param byte_ranges: The byte_ranges of this ProgressiveTsMuxingInformation.
        :type: list[ProgressiveTsMuxingInformationByteRanges]
        """

        if byte_ranges is not None:
            if not isinstance(byte_ranges, list):
                raise TypeError("Invalid type for `byte_ranges`, type has to be `list[ProgressiveTsMuxingInformationByteRanges]`")

        self._byte_ranges = byte_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ProgressiveTsMuxingInformation, self), "to_dict"):
            result = super(ProgressiveTsMuxingInformation, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressiveTsMuxingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.codec_configuration import CodecConfiguration
from bitmovin_api_sdk.models.dts_passthrough_audio_configuration import DtsPassthroughAudioConfiguration
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.dts_passthrough_audio_configuration_list_query_params import DtsPassthroughAudioConfigurationListQueryParams


class DtsPassthroughApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DtsPassthroughApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, dts_passthrough_audio_configuration, **kwargs):
        # type: (DtsPassthroughAudioConfiguration, dict) -> DtsPassthroughAudioConfiguration
        """Create DTS Passthrough Configuration

        :param dts_passthrough_audio_configuration: The DTS Passthrough Codec Configuration to be created
        :type dts_passthrough_audio_configuration: DtsPassthroughAudioConfiguration, required
        :return: DTS Passthrough Audio Configuration
        :rtype: DtsPassthroughAudioConfiguration
        """

        return self.api_client.post(
            '/encoding/configurations/audio/dts-passthrough',
            dts_passthrough_audio_configuration,
            type=DtsPassthroughAudioConfiguration,
            **kwargs
        )

    def delete(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete DTS Passthrough Codec Configuration

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: Id of the codec configuration
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/configurations/audio/dts-passthrough/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> DtsPassthroughAudioConfiguration
        """DTS Passthrough Codec Configuration Details

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: DTS Passthrough Audio Configuration
        :rtype: DtsPassthroughAudioConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/audio/dts-passthrough/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=DtsPassthroughAudioConfiguration,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (DtsPassthroughAudioConfigurationListQueryParams, dict) -> DtsPassthroughAudioConfiguration
        """List DTS Passthrough Configurations

        :param query_params: Query parameters
        :type query_params: DtsPassthroughAudioConfigurationListQueryParams
        :return: List of DTS Passthrough codec configurations
        :rtype: DtsPassthroughAudioConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/audio/dts-passthrough',
            query_params=query_params,
            pagination_response=True,
            type=DtsPassthroughAudioConfiguration,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.check_output_permissions_request import CheckOutputPermissionsRequest
from bitmovin_api_sdk.models.check_output_permissions_response import CheckOutputPermissionsResponse
from bitmovin_api_sdk.models.output import Output
from bitmovin_api_sdk.models.output_type import OutputType
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.outputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.outputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.outputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.outputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.encoding.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.outputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.outputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_api import AkamaiMslApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_api import LiveMediaIngestApi
from bitmovin_api_sdk.encoding.outputs.cdn.cdn_api import CdnApi
from bitmovin_api_sdk.encoding.outputs.output_list_query_params import OutputListQueryParams


class OutputsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OutputsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3 = S3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3_role_based = S3RoleBasedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.generic_s3 = GenericS3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.local = LocalApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs = GcsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs_service_account = GcsServiceAccountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure = AzureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ftp = FtpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sftp = SftpApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai_msl = AkamaiMslApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.akamai_netstorage = AkamaiNetstorageApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.live_media_ingest = LiveMediaIngestApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cdn = CdnApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def check_permissions(self, output_id, check_output_permissions_request=None, **kwargs):
        # type: (string_types, CheckOutputPermissionsRequest, dict) -> CheckOutputPermissionsResponse
        """Check output permissions (S3 only)

        :param output_id: Id of the output to be checked. Currently limited to S3 outputs. The access credentials that have been provided for this Output still need to be valid, otherwise the request will fail. If they are not valid any more, create a new Output with new credentials (resources are immutable).
        :type output_id: string_types, required
        :param check_output_permissions_request: Additional parameters for the permissions check
        :type check_output_permissions_request: CheckOutputPermissionsRequest
        :return: Permissions check result
        :rtype: CheckOutputPermissionsResponse
        """

        return self.api_client.post(
            '/encoding/outputs/{output_id}/check-permissions',
            check_output_permissions_request,
            path_params={'output_id': output_id},
            type=CheckOutputPermissionsResponse,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> Output
        """Get Output Details

        :param output_id: Id of the wanted output
        :type output_id: string_types, required
        :return: Output details
        :rtype: Output
        """

        return self.api_client.get(
            '/encoding/outputs/{output_id}',
            path_params={'output_id': output_id},
            type=Output,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (OutputListQueryParams, dict) -> Output
        """List all Outputs

        :param query_params: Query parameters
        :type query_params: OutputListQueryParams
        :return: All outputs with type information. The specific properties for each type are also included. These are the same as in the list call for a specific type.
        :rtype: Output
        """

        return self.api_client.get(
            '/encoding/outputs',
            query_params=query_params,
            pagination_response=True,
            type=Output,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class S3SignatureVersion(Enum):
    V2 = "S3_V2"
    V4 = "S3_V4"



from bitmovin_api_sdk.encoding.inputs.http.http_api import HttpApi
from bitmovin_api_sdk.encoding.inputs.http.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.http.http_input_list_query_params import HttpInputListQueryParams



from bitmovin_api_sdk.encoding.filters.watermark.watermark_api import WatermarkApi
from bitmovin_api_sdk.encoding.filters.watermark.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.watermark.watermark_filter_list_query_params import WatermarkFilterListQueryParams



from bitmovin_api_sdk.encoding.configurations.video.h262.h262_api import H262Api
from bitmovin_api_sdk.encoding.configurations.video.h262.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.h262.h262_video_configuration_list_query_params import H262VideoConfigurationListQueryParams



from bitmovin_api_sdk.analytics.impressions.impressions_api import ImpressionsApi
from bitmovin_api_sdk.analytics.impressions.ads.ads_api import AdsApi
from bitmovin_api_sdk.analytics.impressions.errors.errors_api import ErrorsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_dynamic_range_compression import DolbyDigitalDynamicRangeCompression
from bitmovin_api_sdk.models.dolby_digital_lfe_low_pass_filter import DolbyDigitalLfeLowPassFilter
from bitmovin_api_sdk.models.dolby_digital_ninety_degree_phase_shift import DolbyDigitalNinetyDegreePhaseShift
from bitmovin_api_sdk.models.dolby_digital_three_db_attenuation import DolbyDigitalThreeDbAttenuation
import pprint
import six


class DolbyDigitalPreprocessing(object):
    @poscheck_model
    def __init__(self,
                 dynamic_range_compression=None,
                 lfe_low_pass_filter=None,
                 ninety_degree_phase_shift=None,
                 three_db_attenuation=None):
        # type: (DolbyDigitalDynamicRangeCompression, DolbyDigitalLfeLowPassFilter, DolbyDigitalNinetyDegreePhaseShift, DolbyDigitalThreeDbAttenuation) -> None

        self._dynamic_range_compression = None
        self._lfe_low_pass_filter = None
        self._ninety_degree_phase_shift = None
        self._three_db_attenuation = None
        self.discriminator = None

        if dynamic_range_compression is not None:
            self.dynamic_range_compression = dynamic_range_compression
        if lfe_low_pass_filter is not None:
            self.lfe_low_pass_filter = lfe_low_pass_filter
        if ninety_degree_phase_shift is not None:
            self.ninety_degree_phase_shift = ninety_degree_phase_shift
        if three_db_attenuation is not None:
            self.three_db_attenuation = three_db_attenuation

    @property
    def openapi_types(self):
        types = {
            'dynamic_range_compression': 'DolbyDigitalDynamicRangeCompression',
            'lfe_low_pass_filter': 'DolbyDigitalLfeLowPassFilter',
            'ninety_degree_phase_shift': 'DolbyDigitalNinetyDegreePhaseShift',
            'three_db_attenuation': 'DolbyDigitalThreeDbAttenuation'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dynamic_range_compression': 'dynamicRangeCompression',
            'lfe_low_pass_filter': 'lfeLowPassFilter',
            'ninety_degree_phase_shift': 'ninetyDegreePhaseShift',
            'three_db_attenuation': 'threeDbAttenuation'
        }
        return attributes

    @property
    def dynamic_range_compression(self):
        # type: () -> DolbyDigitalDynamicRangeCompression
        """Gets the dynamic_range_compression of this DolbyDigitalPreprocessing.

        It indicates a gain change to be applied in the Dolby Digital decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :return: The dynamic_range_compression of this DolbyDigitalPreprocessing.
        :rtype: DolbyDigitalDynamicRangeCompression
        """
        return self._dynamic_range_compression

    @dynamic_range_compression.setter
    def dynamic_range_compression(self, dynamic_range_compression):
        # type: (DolbyDigitalDynamicRangeCompression) -> None
        """Sets the dynamic_range_compression of this DolbyDigitalPreprocessing.

        It indicates a gain change to be applied in the Dolby Digital decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :param dynamic_range_compression: The dynamic_range_compression of this DolbyDigitalPreprocessing.
        :type: DolbyDigitalDynamicRangeCompression
        """

        if dynamic_range_compression is not None:
            if not isinstance(dynamic_range_compression, DolbyDigitalDynamicRangeCompression):
                raise TypeError("Invalid type for `dynamic_range_compression`, type has to be `DolbyDigitalDynamicRangeCompression`")

        self._dynamic_range_compression = dynamic_range_compression

    @property
    def lfe_low_pass_filter(self):
        # type: () -> DolbyDigitalLfeLowPassFilter
        """Gets the lfe_low_pass_filter of this DolbyDigitalPreprocessing.

        It applies a 120 Hz low-pass filter to the low-frequency effects (LFE) channel.  This is only allowed if the `channelLayout` contains a LFE channel. 

        :return: The lfe_low_pass_filter of this DolbyDigitalPreprocessing.
        :rtype: DolbyDigitalLfeLowPassFilter
        """
        return self._lfe_low_pass_filter

    @lfe_low_pass_filter.setter
    def lfe_low_pass_filter(self, lfe_low_pass_filter):
        # type: (DolbyDigitalLfeLowPassFilter) -> None
        """Sets the lfe_low_pass_filter of this DolbyDigitalPreprocessing.

        It applies a 120 Hz low-pass filter to the low-frequency effects (LFE) channel.  This is only allowed if the `channelLayout` contains a LFE channel. 

        :param lfe_low_pass_filter: The lfe_low_pass_filter of this DolbyDigitalPreprocessing.
        :type: DolbyDigitalLfeLowPassFilter
        """

        if lfe_low_pass_filter is not None:
            if not isinstance(lfe_low_pass_filter, DolbyDigitalLfeLowPassFilter):
                raise TypeError("Invalid type for `lfe_low_pass_filter`, type has to be `DolbyDigitalLfeLowPassFilter`")

        self._lfe_low_pass_filter = lfe_low_pass_filter

    @property
    def ninety_degree_phase_shift(self):
        # type: () -> DolbyDigitalNinetyDegreePhaseShift
        """Gets the ninety_degree_phase_shift of this DolbyDigitalPreprocessing.


        :return: The ninety_degree_phase_shift of this DolbyDigitalPreprocessing.
        :rtype: DolbyDigitalNinetyDegreePhaseShift
        """
        return self._ninety_degree_phase_shift

    @ninety_degree_phase_shift.setter
    def ninety_degree_phase_shift(self, ninety_degree_phase_shift):
        # type: (DolbyDigitalNinetyDegreePhaseShift) -> None
        """Sets the ninety_degree_phase_shift of this DolbyDigitalPreprocessing.


        :param ninety_degree_phase_shift: The ninety_degree_phase_shift of this DolbyDigitalPreprocessing.
        :type: DolbyDigitalNinetyDegreePhaseShift
        """

        if ninety_degree_phase_shift is not None:
            if not isinstance(ninety_degree_phase_shift, DolbyDigitalNinetyDegreePhaseShift):
                raise TypeError("Invalid type for `ninety_degree_phase_shift`, type has to be `DolbyDigitalNinetyDegreePhaseShift`")

        self._ninety_degree_phase_shift = ninety_degree_phase_shift

    @property
    def three_db_attenuation(self):
        # type: () -> DolbyDigitalThreeDbAttenuation
        """Gets the three_db_attenuation of this DolbyDigitalPreprocessing.


        :return: The three_db_attenuation of this DolbyDigitalPreprocessing.
        :rtype: DolbyDigitalThreeDbAttenuation
        """
        return self._three_db_attenuation

    @three_db_attenuation.setter
    def three_db_attenuation(self, three_db_attenuation):
        # type: (DolbyDigitalThreeDbAttenuation) -> None
        """Sets the three_db_attenuation of this DolbyDigitalPreprocessing.


        :param three_db_attenuation: The three_db_attenuation of this DolbyDigitalPreprocessing.
        :type: DolbyDigitalThreeDbAttenuation
        """

        if three_db_attenuation is not None:
            if not isinstance(three_db_attenuation, DolbyDigitalThreeDbAttenuation):
                raise TypeError("Invalid type for `three_db_attenuation`, type has to be `DolbyDigitalThreeDbAttenuation`")

        self._three_db_attenuation = three_db_attenuation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalPreprocessing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.filters.denoise_hqdn3d.denoise_hqdn3d_api import DenoiseHqdn3dApi
from bitmovin_api_sdk.encoding.filters.denoise_hqdn3d.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.denoise_hqdn3d.denoise_hqdn3d_filter_list_query_params import DenoiseHqdn3dFilterListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_infos import StreamInfos
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.streams.stream_infos_list_query_params import StreamInfosListQueryParams


class StreamsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StreamsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, StreamInfosListQueryParams, dict) -> StreamInfos
        """List Stream Infos of Live Statistics from an Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: StreamInfosListQueryParams
        :return: List of statistics
        :rtype: StreamInfos
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/{encoding_id}/live-statistics/streams',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=StreamInfos,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AdAnalyticsAttribute(Enum):
    AD_IMPRESSION_ID = "AD_IMPRESSION_ID"
    AD_CLICKTHROUGH_URL = "AD_CLICKTHROUGH_URL"
    AD_DESCRIPTION = "AD_DESCRIPTION"
    AD_DURATION = "AD_DURATION"
    AD_FALLBACK_INDEX = "AD_FALLBACK_INDEX"
    AD_ID = "AD_ID"
    AD_ID_PLAYER = "AD_ID_PLAYER"
    AD_IS_PERSISTENT = "AD_IS_PERSISTENT"
    AD_MODULE = "AD_MODULE"
    AD_OFFSET = "AD_OFFSET"
    AD_PLAYBACK_HEIGHT = "AD_PLAYBACK_HEIGHT"
    AD_PLAYBACK_WIDTH = "AD_PLAYBACK_WIDTH"
    AD_POD_POSITION = "AD_POD_POSITION"
    AD_POSITION = "AD_POSITION"
    AD_PRELOAD_OFFSET = "AD_PRELOAD_OFFSET"
    AD_REPLACE_CONTENT_DURATION = "AD_REPLACE_CONTENT_DURATION"
    AD_SCHEDULE_TIME = "AD_SCHEDULE_TIME"
    AD_SKIP_AFTER = "AD_SKIP_AFTER"
    AD_SKIPPABLE = "AD_SKIPPABLE"
    AD_STARTUP_TIME = "AD_STARTUP_TIME"
    AD_SYSTEM = "AD_SYSTEM"
    AD_TAG_PATH = "AD_TAG_PATH"
    AD_TAG_SERVER = "AD_TAG_SERVER"
    AD_TAG_TYPE = "AD_TAG_TYPE"
    AD_TAG_URL = "AD_TAG_URL"
    AD_TITLE = "AD_TITLE"
    AD_WRAPPER_ADS_COUNT = "AD_WRAPPER_ADS_COUNT"
    ADVERTISER_NAME = "ADVERTISER_NAME"
    ANALYTICS_VERSION = "ANALYTICS_VERSION"
    API_FRAMEWORK = "API_FRAMEWORK"
    AUDIO_BITRATE = "AUDIO_BITRATE"
    AUDIO_CODEC = "AUDIO_CODEC"
    AUTOPLAY = "AUTOPLAY"
    BROWSER = "BROWSER"
    BROWSER_VERSION_MAJOR = "BROWSER_VERSION_MAJOR"
    CDN_PROVIDER = "CDN_PROVIDER"
    CITY = "CITY"
    CLICK_PERCENTAGE = "CLICK_PERCENTAGE"
    CLICK_POSITION = "CLICK_POSITION"
    CLICKED = "CLICKED"
    CLIENT_TIME = "CLIENT_TIME"
    CLOSE_PERCENTAGE = "CLOSE_PERCENTAGE"
    CLOSE_POSITION = "CLOSE_POSITION"
    CLOSED = "CLOSED"
    COMPLETED = "COMPLETED"
    COUNTRY = "COUNTRY"
    CREATIVE_AD_ID = "CREATIVE_AD_ID"
    CREATIVE_ID = "CREATIVE_ID"
    CUSTOM_DATA_1 = "CUSTOM_DATA_1"
    CUSTOM_DATA_2 = "CUSTOM_DATA_2"
    CUSTOM_DATA_3 = "CUSTOM_DATA_3"
    CUSTOM_DATA_4 = "CUSTOM_DATA_4"
    CUSTOM_DATA_5 = "CUSTOM_DATA_5"
    CUSTOM_DATA_6 = "CUSTOM_DATA_6"
    CUSTOM_DATA_7 = "CUSTOM_DATA_7"
    CUSTOM_DATA_8 = "CUSTOM_DATA_8"
    CUSTOM_DATA_9 = "CUSTOM_DATA_9"
    CUSTOM_DATA_10 = "CUSTOM_DATA_10"
    CUSTOM_DATA_11 = "CUSTOM_DATA_11"
    CUSTOM_DATA_12 = "CUSTOM_DATA_12"
    CUSTOM_DATA_13 = "CUSTOM_DATA_13"
    CUSTOM_DATA_14 = "CUSTOM_DATA_14"
    CUSTOM_DATA_15 = "CUSTOM_DATA_15"
    CUSTOM_DATA_16 = "CUSTOM_DATA_16"
    CUSTOM_DATA_17 = "CUSTOM_DATA_17"
    CUSTOM_DATA_18 = "CUSTOM_DATA_18"
    CUSTOM_DATA_19 = "CUSTOM_DATA_19"
    CUSTOM_DATA_20 = "CUSTOM_DATA_20"
    CUSTOM_DATA_21 = "CUSTOM_DATA_21"
    CUSTOM_DATA_22 = "CUSTOM_DATA_22"
    CUSTOM_DATA_23 = "CUSTOM_DATA_23"
    CUSTOM_DATA_24 = "CUSTOM_DATA_24"
    CUSTOM_DATA_25 = "CUSTOM_DATA_25"
    CUSTOM_DATA_26 = "CUSTOM_DATA_26"
    CUSTOM_DATA_27 = "CUSTOM_DATA_27"
    CUSTOM_DATA_28 = "CUSTOM_DATA_28"
    CUSTOM_DATA_29 = "CUSTOM_DATA_29"
    CUSTOM_DATA_30 = "CUSTOM_DATA_30"
    CUSTOM_USER_ID = "CUSTOM_USER_ID"
    DAY = "DAY"
    DEAL_ID = "DEAL_ID"
    DEVICE_CLASS = "DEVICE_CLASS"
    DEVICE_TYPE = "DEVICE_TYPE"
    DOMAIN = "DOMAIN"
    ERROR_CODE = "ERROR_CODE"
    ERROR_PERCENTAGE = "ERROR_PERCENTAGE"
    ERROR_POSITION = "ERROR_POSITION"
    EXIT_POSITION = "EXIT_POSITION"
    EXPERIMENT_NAME = "EXPERIMENT_NAME"
    HOUR = "HOUR"
    IP_ADDRESS = "IP_ADDRESS"
    IS_LINEAR = "IS_LINEAR"
    ISP = "ISP"
    LANGUAGE = "LANGUAGE"
    LICENSE_KEY = "LICENSE_KEY"
    MANIFEST_DOWNLOAD_TIME = "MANIFEST_DOWNLOAD_TIME"
    MEDIA_PATH = "MEDIA_PATH"
    MEDIA_SERVER = "MEDIA_SERVER"
    MEDIA_URL = "MEDIA_URL"
    MIDPOINT = "MIDPOINT"
    MIN_SUGGESTED_DURATION = "MIN_SUGGESTED_DURATION"
    MINUTE = "MINUTE"
    MONTH = "MONTH"
    OPERATINGSYSTEM = "OPERATINGSYSTEM"
    OPERATINGSYSTEM_VERSION_MAJOR = "OPERATINGSYSTEM_VERSION_MAJOR"
    PAGE_LOAD_TIME = "PAGE_LOAD_TIME"
    PAGE_LOAD_TYPE = "PAGE_LOAD_TYPE"
    PATH = "PATH"
    PERCENTAGE_IN_VIEWPORT = "PERCENTAGE_IN_VIEWPORT"
    PLATFORM = "PLATFORM"
    PLAY_PERCENTAGE = "PLAY_PERCENTAGE"
    PLAYER = "PLAYER"
    PLAYER_KEY = "PLAYER_KEY"
    PLAYER_STARTUPTIME = "PLAYER_STARTUPTIME"
    PLAYER_TECH = "PLAYER_TECH"
    PLAYER_VERSION = "PLAYER_VERSION"
    QUARTILE_1 = "QUARTILE_1"
    QUARTILE_3 = "QUARTILE_3"
    REGION = "REGION"
    SCALE_FACTOR = "SCALE_FACTOR"
    SCREEN_HEIGHT = "SCREEN_HEIGHT"
    SCREEN_WIDTH = "SCREEN_WIDTH"
    SCREEN_ORIENTATION = "SCREEN_ORIENTATION"
    SIZE = "SIZE"
    SKIP_PERCENTAGE = "SKIP_PERCENTAGE"
    SKIP_POSITION = "SKIP_POSITION"
    SKIPPED = "SKIPPED"
    STARTED = "STARTED"
    STREAM_FORMAT = "STREAM_FORMAT"
    SURVEY_URL = "SURVEY_URL"
    TIME = "TIME"
    TIME_IN_VIEWPORT = "TIME_IN_VIEWPORT"
    TIME_PLAYED = "TIME_PLAYED"
    UNIVERSAL_AD_ID_REGISTRY = "UNIVERSAL_AD_ID_REGISTRY"
    UNIVERSAL_AD_ID_VALUE = "UNIVERSAL_AD_ID_VALUE"
    USER_ID = "USER_ID"
    VIDEO_BITRATE = "VIDEO_BITRATE"
    VIDEO_CODEC = "VIDEO_CODEC"
    VIDEO_ID = "VIDEO_ID"
    VIDEO_IMPRESSION_ID = "VIDEO_IMPRESSION_ID"
    VIDEO_TITLE = "VIDEO_TITLE"
    VIDEO_WINDOW_HEIGHT = "VIDEO_WINDOW_HEIGHT"
    VIDEO_WINDOW_WIDTH = "VIDEO_WINDOW_WIDTH"



from bitmovin_api_sdk.encoding.manifests.dash.periods.custom_xml_elements.custom_xml_elements_api import CustomXmlElementsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.custom_xml_elements.custom_xml_element_list_query_params import CustomXmlElementListQueryParams



from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.streams.stream_infos_list_query_params import StreamInfosListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsQueryOperator(Enum):
    IN = "IN"
    EQ = "EQ"
    NE = "NE"
    LT = "LT"
    LTE = "LTE"
    GT = "GT"
    GTE = "GTE"
    CONTAINS = "CONTAINS"
    NOTCONTAINS = "NOTCONTAINS"



# coding: utf-8

from enum import Enum
from datetime import date
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EncodingStats(object):
    @poscheck_model
    def __init__(self,
                 date_=None,
                 encoding_id=None,
                 bytes_encoded=None,
                 time_encoded=None,
                 downloaded_size=None,
                 billable_minutes=None,
                 billable_egress_bytes=None,
                 billable_encoding_minutes=None,
                 billable_transmuxing_minutes=None,
                 billable_feature_minutes=None,
                 streams=None,
                 muxings=None,
                 features=None):
        # type: (date, string_types, int, int, int, float, list[EgressInformation], list[BillableEncodingMinutes], float, float, list[StatisticsPerStream], list[StatisticsPerMuxing], list[BillableEncodingFeatureMinutes]) -> None

        self._date = None
        self._encoding_id = None
        self._bytes_encoded = None
        self._time_encoded = None
        self._downloaded_size = None
        self._billable_minutes = None
        self._billable_egress_bytes = list()
        self._billable_encoding_minutes = list()
        self._billable_transmuxing_minutes = None
        self._billable_feature_minutes = None
        self._streams = list()
        self._muxings = list()
        self._features = list()
        self.discriminator = None

        if date_ is not None:
            self.date = date_
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if bytes_encoded is not None:
            self.bytes_encoded = bytes_encoded
        if time_encoded is not None:
            self.time_encoded = time_encoded
        if downloaded_size is not None:
            self.downloaded_size = downloaded_size
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes
        if billable_egress_bytes is not None:
            self.billable_egress_bytes = billable_egress_bytes
        if billable_encoding_minutes is not None:
            self.billable_encoding_minutes = billable_encoding_minutes
        if billable_transmuxing_minutes is not None:
            self.billable_transmuxing_minutes = billable_transmuxing_minutes
        if billable_feature_minutes is not None:
            self.billable_feature_minutes = billable_feature_minutes
        if streams is not None:
            self.streams = streams
        if muxings is not None:
            self.muxings = muxings
        if features is not None:
            self.features = features

    @property
    def openapi_types(self):
        types = {
            'date': 'date',
            'encoding_id': 'string_types',
            'bytes_encoded': 'int',
            'time_encoded': 'int',
            'downloaded_size': 'int',
            'billable_minutes': 'float',
            'billable_egress_bytes': 'list[EgressInformation]',
            'billable_encoding_minutes': 'list[BillableEncodingMinutes]',
            'billable_transmuxing_minutes': 'float',
            'billable_feature_minutes': 'float',
            'streams': 'list[StatisticsPerStream]',
            'muxings': 'list[StatisticsPerMuxing]',
            'features': 'list[BillableEncodingFeatureMinutes]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'date': 'date',
            'encoding_id': 'encodingId',
            'bytes_encoded': 'bytesEncoded',
            'time_encoded': 'timeEncoded',
            'downloaded_size': 'downloadedSize',
            'billable_minutes': 'billableMinutes',
            'billable_egress_bytes': 'billableEgressBytes',
            'billable_encoding_minutes': 'billableEncodingMinutes',
            'billable_transmuxing_minutes': 'billableTransmuxingMinutes',
            'billable_feature_minutes': 'billableFeatureMinutes',
            'streams': 'streams',
            'muxings': 'muxings',
            'features': 'features'
        }
        return attributes

    @property
    def date(self):
        # type: () -> date
        """Gets the date of this EncodingStats.

        Date, format. yyyy-MM-dd

        :return: The date of this EncodingStats.
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date_):
        # type: (date) -> None
        """Sets the date of this EncodingStats.

        Date, format. yyyy-MM-dd

        :param date_: The date of this EncodingStats.
        :type: date
        """

        if date_ is not None:
            if not isinstance(date_, date):
                raise TypeError("Invalid type for `date`, type has to be `date`")

        self._date = date_

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this EncodingStats.

        The id of the encoding (required)

        :return: The encoding_id of this EncodingStats.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this EncodingStats.

        The id of the encoding (required)

        :param encoding_id: The encoding_id of this EncodingStats.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def bytes_encoded(self):
        # type: () -> int
        """Gets the bytes_encoded of this EncodingStats.

        Total bytes encoded

        :return: The bytes_encoded of this EncodingStats.
        :rtype: int
        """
        return self._bytes_encoded

    @bytes_encoded.setter
    def bytes_encoded(self, bytes_encoded):
        # type: (int) -> None
        """Sets the bytes_encoded of this EncodingStats.

        Total bytes encoded

        :param bytes_encoded: The bytes_encoded of this EncodingStats.
        :type: int
        """

        if bytes_encoded is not None:
            if not isinstance(bytes_encoded, int):
                raise TypeError("Invalid type for `bytes_encoded`, type has to be `int`")

        self._bytes_encoded = bytes_encoded

    @property
    def time_encoded(self):
        # type: () -> int
        """Gets the time_encoded of this EncodingStats.

        Total time encoded

        :return: The time_encoded of this EncodingStats.
        :rtype: int
        """
        return self._time_encoded

    @time_encoded.setter
    def time_encoded(self, time_encoded):
        # type: (int) -> None
        """Sets the time_encoded of this EncodingStats.

        Total time encoded

        :param time_encoded: The time_encoded of this EncodingStats.
        :type: int
        """

        if time_encoded is not None:
            if not isinstance(time_encoded, int):
                raise TypeError("Invalid type for `time_encoded`, type has to be `int`")

        self._time_encoded = time_encoded

    @property
    def downloaded_size(self):
        # type: () -> int
        """Gets the downloaded_size of this EncodingStats.

        Downloaded size of the input file

        :return: The downloaded_size of this EncodingStats.
        :rtype: int
        """
        return self._downloaded_size

    @downloaded_size.setter
    def downloaded_size(self, downloaded_size):
        # type: (int) -> None
        """Sets the downloaded_size of this EncodingStats.

        Downloaded size of the input file

        :param downloaded_size: The downloaded_size of this EncodingStats.
        :type: int
        """

        if downloaded_size is not None:
            if not isinstance(downloaded_size, int):
                raise TypeError("Invalid type for `downloaded_size`, type has to be `int`")

        self._downloaded_size = downloaded_size

    @property
    def billable_minutes(self):
        # type: () -> float
        """Gets the billable_minutes of this EncodingStats.

        Billable minutes

        :return: The billable_minutes of this EncodingStats.
        :rtype: float
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (float) -> None
        """Sets the billable_minutes of this EncodingStats.

        Billable minutes

        :param billable_minutes: The billable_minutes of this EncodingStats.
        :type: float
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `float`")

        self._billable_minutes = billable_minutes

    @property
    def billable_egress_bytes(self):
        # type: () -> list[EgressInformation]
        """Gets the billable_egress_bytes of this EncodingStats.

        Billable egress output

        :return: The billable_egress_bytes of this EncodingStats.
        :rtype: list[EgressInformation]
        """
        return self._billable_egress_bytes

    @billable_egress_bytes.setter
    def billable_egress_bytes(self, billable_egress_bytes):
        # type: (list) -> None
        """Sets the billable_egress_bytes of this EncodingStats.

        Billable egress output

        :param billable_egress_bytes: The billable_egress_bytes of this EncodingStats.
        :type: list[EgressInformation]
        """

        if billable_egress_bytes is not None:
            if not isinstance(billable_egress_bytes, list):
                raise TypeError("Invalid type for `billable_egress_bytes`, type has to be `list[EgressInformation]`")

        self._billable_egress_bytes = billable_egress_bytes

    @property
    def billable_encoding_minutes(self):
        # type: () -> list[BillableEncodingMinutes]
        """Gets the billable_encoding_minutes of this EncodingStats.

        Detailed statistics per stream

        :return: The billable_encoding_minutes of this EncodingStats.
        :rtype: list[BillableEncodingMinutes]
        """
        return self._billable_encoding_minutes

    @billable_encoding_minutes.setter
    def billable_encoding_minutes(self, billable_encoding_minutes):
        # type: (list) -> None
        """Sets the billable_encoding_minutes of this EncodingStats.

        Detailed statistics per stream

        :param billable_encoding_minutes: The billable_encoding_minutes of this EncodingStats.
        :type: list[BillableEncodingMinutes]
        """

        if billable_encoding_minutes is not None:
            if not isinstance(billable_encoding_minutes, list):
                raise TypeError("Invalid type for `billable_encoding_minutes`, type has to be `list[BillableEncodingMinutes]`")

        self._billable_encoding_minutes = billable_encoding_minutes

    @property
    def billable_transmuxing_minutes(self):
        # type: () -> float
        """Gets the billable_transmuxing_minutes of this EncodingStats.

        Billable transmuxing minutes (required)

        :return: The billable_transmuxing_minutes of this EncodingStats.
        :rtype: float
        """
        return self._billable_transmuxing_minutes

    @billable_transmuxing_minutes.setter
    def billable_transmuxing_minutes(self, billable_transmuxing_minutes):
        # type: (float) -> None
        """Sets the billable_transmuxing_minutes of this EncodingStats.

        Billable transmuxing minutes (required)

        :param billable_transmuxing_minutes: The billable_transmuxing_minutes of this EncodingStats.
        :type: float
        """

        if billable_transmuxing_minutes is not None:
            if not isinstance(billable_transmuxing_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_transmuxing_minutes`, type has to be `float`")

        self._billable_transmuxing_minutes = billable_transmuxing_minutes

    @property
    def billable_feature_minutes(self):
        # type: () -> float
        """Gets the billable_feature_minutes of this EncodingStats.

        Billable feature minutes

        :return: The billable_feature_minutes of this EncodingStats.
        :rtype: float
        """
        return self._billable_feature_minutes

    @billable_feature_minutes.setter
    def billable_feature_minutes(self, billable_feature_minutes):
        # type: (float) -> None
        """Sets the billable_feature_minutes of this EncodingStats.

        Billable feature minutes

        :param billable_feature_minutes: The billable_feature_minutes of this EncodingStats.
        :type: float
        """

        if billable_feature_minutes is not None:
            if not isinstance(billable_feature_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_feature_minutes`, type has to be `float`")

        self._billable_feature_minutes = billable_feature_minutes

    @property
    def streams(self):
        # type: () -> list[StatisticsPerStream]
        """Gets the streams of this EncodingStats.

        Detailed statistics per stream (required)

        :return: The streams of this EncodingStats.
        :rtype: list[StatisticsPerStream]
        """
        return self._streams

    @streams.setter
    def streams(self, streams):
        # type: (list) -> None
        """Sets the streams of this EncodingStats.

        Detailed statistics per stream (required)

        :param streams: The streams of this EncodingStats.
        :type: list[StatisticsPerStream]
        """

        if streams is not None:
            if not isinstance(streams, list):
                raise TypeError("Invalid type for `streams`, type has to be `list[StatisticsPerStream]`")

        self._streams = streams

    @property
    def muxings(self):
        # type: () -> list[StatisticsPerMuxing]
        """Gets the muxings of this EncodingStats.

        Detailed statistics per muxing (required)

        :return: The muxings of this EncodingStats.
        :rtype: list[StatisticsPerMuxing]
        """
        return self._muxings

    @muxings.setter
    def muxings(self, muxings):
        # type: (list) -> None
        """Sets the muxings of this EncodingStats.

        Detailed statistics per muxing (required)

        :param muxings: The muxings of this EncodingStats.
        :type: list[StatisticsPerMuxing]
        """

        if muxings is not None:
            if not isinstance(muxings, list):
                raise TypeError("Invalid type for `muxings`, type has to be `list[StatisticsPerMuxing]`")

        self._muxings = muxings

    @property
    def features(self):
        # type: () -> list[BillableEncodingFeatureMinutes]
        """Gets the features of this EncodingStats.

        Detailed statistics per feature

        :return: The features of this EncodingStats.
        :rtype: list[BillableEncodingFeatureMinutes]
        """
        return self._features

    @features.setter
    def features(self, features):
        # type: (list) -> None
        """Sets the features of this EncodingStats.

        Detailed statistics per feature

        :param features: The features of this EncodingStats.
        :type: list[BillableEncodingFeatureMinutes]
        """

        if features is not None:
            if not isinstance(features, list):
                raise TypeError("Invalid type for `features`, type has to be `list[BillableEncodingFeatureMinutes]`")

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncodingStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.common.api_client import ApiClient
from bitmovin_api_sdk.common.poscheck import poscheck_except


class BaseApi(object):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        self.api_client = ApiClient(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveEncodingCodec(Enum):
    H264 = "H264"
    H265 = "H265"
    AAC = "AAC"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_mode import StreamMode
from bitmovin_api_sdk.encoding.encodings.muxings.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.encodings.muxings.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.encodings.muxings.segmented_raw.segmented_raw_api import SegmentedRawApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.packed_audio_api import PackedAudioApi
from bitmovin_api_sdk.encoding.encodings.muxings.text.text_api import TextApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.ts_api import TsApi
from bitmovin_api_sdk.encoding.encodings.muxings.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp3.mp3_api import Mp3Api
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.encodings.muxings.mxf.mxf_api import MxfApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.progressive_ts_api import ProgressiveTsApi
from bitmovin_api_sdk.encoding.encodings.muxings.broadcast_ts.broadcast_ts_api import BroadcastTsApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.progressive_webm_api import ProgressiveWebmApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_mov.progressive_mov_api import ProgressiveMovApi
from bitmovin_api_sdk.encoding.encodings.muxings.muxing_list_query_params import MuxingListQueryParams


class MuxingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(MuxingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.fmp4 = Fmp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.chunked_text = ChunkedTextApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cmaf = CmafApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.segmented_raw = SegmentedRawApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.packed_audio = PackedAudioApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.text = TextApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ts = TsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.webm = WebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp3 = Mp3Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp4 = Mp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mxf = MxfApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.progressive_ts = ProgressiveTsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.broadcast_ts = BroadcastTsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.progressive_webm = ProgressiveWebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.progressive_mov = ProgressiveMovApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> Muxing
        """Muxing Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the muxing.
        :type muxing_id: string_types, required
        :return: Muxing details
        :rtype: Muxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/{muxing_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=Muxing,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, MuxingListQueryParams, dict) -> Muxing
        """List All Muxings

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: MuxingListQueryParams
        :return: List of muxings
        :rtype: Muxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Muxing,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.live_encoding import LiveEncoding
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.start_live_encoding_request import StartLiveEncodingRequest
from bitmovin_api_sdk.encoding.encodings.live.hd.hd_api import HdApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_api import InsertableContentApi
from bitmovin_api_sdk.encoding.encodings.live.scte35_cue.scte35_cue_api import Scte35CueApi


class LiveApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.hd = HdApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.insertable_content = InsertableContentApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.scte35_cue = Scte35CueApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> LiveEncoding
        """Live Encoding Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: Encoding
        :rtype: LiveEncoding
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/live',
            path_params={'encoding_id': encoding_id},
            type=LiveEncoding,
            **kwargs
        )

    def get_start_request(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> StartLiveEncodingRequest
        """Live Encoding Start Details

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: Service specific result
        :rtype: StartLiveEncodingRequest
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/live/start',
            path_params={'encoding_id': encoding_id},
            type=StartLiveEncodingRequest,
            **kwargs
        )

    def restart(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Re-Start Live Encoding

        :param encoding_id: Id of the encoding.  **Important:** Only live encodings with the status &#x60;RUNNING&#x60;, &#x60;FINISHED&#x60;, &#x60;CANCELED&#x60; or &#x60;ERROR&#x60; can be restarted. 
        :type encoding_id: string_types, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/restart',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def start(self, encoding_id, start_live_encoding_request, **kwargs):
        # type: (string_types, StartLiveEncodingRequest, dict) -> BitmovinResponse
        """Start Live Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param start_live_encoding_request: Live Encoding startup options
        :type start_live_encoding_request: StartLiveEncodingRequest, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/start',
            start_live_encoding_request,
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )

    def stop(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop Live Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: Id of the encoding
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/stop',
            path_params={'encoding_id': encoding_id},
            type=BitmovinResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.live_encoding_options_statistics import LiveEncodingOptionsStatistics
from bitmovin_api_sdk.models.live_options_statistics import LiveOptionsStatistics
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.statistics.encodings.live.options.live_options_statistics_list_by_date_range_query_params import LiveOptionsStatisticsListByDateRangeQueryParams


class OptionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OptionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> LiveEncodingOptionsStatistics
        """List live options encoding statistics for a given encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return:
        :rtype: LiveEncodingOptionsStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/live/{encoding_id}/options',
            path_params={'encoding_id': encoding_id},
            type=LiveEncodingOptionsStatistics,
            **kwargs
        )

    def list_by_date_range(self, query_params=None, **kwargs):
        # type: (LiveOptionsStatisticsListByDateRangeQueryParams, dict) -> LiveOptionsStatistics
        """List live options encoding statistics within specific dates

        :param query_params: Query parameters
        :type query_params: LiveOptionsStatisticsListByDateRangeQueryParams
        :return:
        :rtype: LiveOptionsStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/live/options',
            query_params=query_params,
            type=LiveOptionsStatistics,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.webhook import Webhook


class FinishedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(FinishedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, webhook, **kwargs):
        # type: (Webhook, dict) -> Webhook
        """Add &#39;Manifest Finished Successfully&#39; Webhook (All Manifests)

        :param webhook: Add a new webhook notification that triggers if a manifest generation finished successfully. A maximum number of 5 webhooks is allowed
        :type webhook: Webhook, required
        :return: Webhook Details
        :rtype: Webhook
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/manifest/finished',
            webhook,
            type=Webhook,
            **kwargs
        )

    def create_by_manifest_id(self, manifest_id, webhook, **kwargs):
        # type: (string_types, Webhook, dict) -> Webhook
        """Add &#39;Manifest Finished Successfully&#39; Webhook Notification (Specific Manifest)

        :param manifest_id: Id of the manifest resource
        :type manifest_id: string_types, required
        :param webhook: The webhook notifications object. A maximum number of 5 webhooks per Manifest is allowed
        :type webhook: Webhook, required
        :return: Notification Details
        :rtype: Webhook
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/manifest/{manifest_id}/finished',
            webhook,
            path_params={'manifest_id': manifest_id},
            type=Webhook,
            **kwargs
        )

    def delete(self, notification_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Manifest Finished Webhook

        :param notification_id: Id of the webhook notification
        :type notification_id: string_types, required
        :return: Id of the webhook
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/webhooks/encoding/manifest/finished/{notification_id}',
            path_params={'notification_id': notification_id},
            type=BitmovinResponse,
            **kwargs
        )

    def update(self, notification_id, webhook, **kwargs):
        # type: (string_types, Webhook, dict) -> Webhook
        """Replace Manifest Finished Webhook Notification

        :param notification_id: Id of the webhook notification
        :type notification_id: string_types, required
        :param webhook: The webhook notification with the updated values
        :type webhook: Webhook, required
        :return: Notification Details
        :rtype: Webhook
        """

        return self.api_client.put(
            '/notifications/webhooks/encoding/manifest/finished/{notification_id}',
            webhook,
            path_params={'notification_id': notification_id},
            type=Webhook,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PositionMode(Enum):
    KEYFRAME = "KEYFRAME"
    TIME = "TIME"
    SEGMENT = "SEGMENT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_representation import AutoRepresentation
from bitmovin_api_sdk.models.per_title_configuration import PerTitleConfiguration
from bitmovin_api_sdk.models.per_title_fixed_resolution_and_bitrate_configuration import PerTitleFixedResolutionAndBitrateConfiguration
import pprint
import six


class H265PerTitleConfiguration(PerTitleConfiguration):
    @poscheck_model
    def __init__(self,
                 min_bitrate=None,
                 max_bitrate=None,
                 min_bitrate_step_size=None,
                 max_bitrate_step_size=None,
                 auto_representations=None,
                 complexity_factor=None,
                 fixed_resolution_and_bitrate_configuration=None,
                 target_quality_crf=None,
                 codec_min_bitrate_factor=None,
                 codec_max_bitrate_factor=None,
                 codec_bufsize_factor=None):
        # type: (int, int, float, float, AutoRepresentation, float, PerTitleFixedResolutionAndBitrateConfiguration, float, float, float, float) -> None
        super(H265PerTitleConfiguration, self).__init__(min_bitrate=min_bitrate, max_bitrate=max_bitrate, min_bitrate_step_size=min_bitrate_step_size, max_bitrate_step_size=max_bitrate_step_size, auto_representations=auto_representations, complexity_factor=complexity_factor, fixed_resolution_and_bitrate_configuration=fixed_resolution_and_bitrate_configuration)

        self._target_quality_crf = None
        self._codec_min_bitrate_factor = None
        self._codec_max_bitrate_factor = None
        self._codec_bufsize_factor = None
        self.discriminator = None

        if target_quality_crf is not None:
            self.target_quality_crf = target_quality_crf
        if codec_min_bitrate_factor is not None:
            self.codec_min_bitrate_factor = codec_min_bitrate_factor
        if codec_max_bitrate_factor is not None:
            self.codec_max_bitrate_factor = codec_max_bitrate_factor
        if codec_bufsize_factor is not None:
            self.codec_bufsize_factor = codec_bufsize_factor

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(H265PerTitleConfiguration, self), 'openapi_types'):
            types = getattr(super(H265PerTitleConfiguration, self), 'openapi_types')

        types.update({
            'target_quality_crf': 'float',
            'codec_min_bitrate_factor': 'float',
            'codec_max_bitrate_factor': 'float',
            'codec_bufsize_factor': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(H265PerTitleConfiguration, self), 'attribute_map'):
            attributes = getattr(super(H265PerTitleConfiguration, self), 'attribute_map')

        attributes.update({
            'target_quality_crf': 'targetQualityCrf',
            'codec_min_bitrate_factor': 'codecMinBitrateFactor',
            'codec_max_bitrate_factor': 'codecMaxBitrateFactor',
            'codec_bufsize_factor': 'codecBufsizeFactor'
        })
        return attributes

    @property
    def target_quality_crf(self):
        # type: () -> float
        """Gets the target_quality_crf of this H265PerTitleConfiguration.

        Desired target quality of the highest representation expressed as CRF value

        :return: The target_quality_crf of this H265PerTitleConfiguration.
        :rtype: float
        """
        return self._target_quality_crf

    @target_quality_crf.setter
    def target_quality_crf(self, target_quality_crf):
        # type: (float) -> None
        """Sets the target_quality_crf of this H265PerTitleConfiguration.

        Desired target quality of the highest representation expressed as CRF value

        :param target_quality_crf: The target_quality_crf of this H265PerTitleConfiguration.
        :type: float
        """

        if target_quality_crf is not None:
            if not isinstance(target_quality_crf, (float, int)):
                raise TypeError("Invalid type for `target_quality_crf`, type has to be `float`")

        self._target_quality_crf = target_quality_crf

    @property
    def codec_min_bitrate_factor(self):
        # type: () -> float
        """Gets the codec_min_bitrate_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the minBitrate of the codec configuration for the generated representations as a multiple of the targetBitrate

        :return: The codec_min_bitrate_factor of this H265PerTitleConfiguration.
        :rtype: float
        """
        return self._codec_min_bitrate_factor

    @codec_min_bitrate_factor.setter
    def codec_min_bitrate_factor(self, codec_min_bitrate_factor):
        # type: (float) -> None
        """Sets the codec_min_bitrate_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the minBitrate of the codec configuration for the generated representations as a multiple of the targetBitrate

        :param codec_min_bitrate_factor: The codec_min_bitrate_factor of this H265PerTitleConfiguration.
        :type: float
        """

        if codec_min_bitrate_factor is not None:
            if not isinstance(codec_min_bitrate_factor, (float, int)):
                raise TypeError("Invalid type for `codec_min_bitrate_factor`, type has to be `float`")

        self._codec_min_bitrate_factor = codec_min_bitrate_factor

    @property
    def codec_max_bitrate_factor(self):
        # type: () -> float
        """Gets the codec_max_bitrate_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the maxBitrate of the codec configuration for the generated representations as a multiple of the targetBitrate

        :return: The codec_max_bitrate_factor of this H265PerTitleConfiguration.
        :rtype: float
        """
        return self._codec_max_bitrate_factor

    @codec_max_bitrate_factor.setter
    def codec_max_bitrate_factor(self, codec_max_bitrate_factor):
        # type: (float) -> None
        """Sets the codec_max_bitrate_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the maxBitrate of the codec configuration for the generated representations as a multiple of the targetBitrate

        :param codec_max_bitrate_factor: The codec_max_bitrate_factor of this H265PerTitleConfiguration.
        :type: float
        """

        if codec_max_bitrate_factor is not None:
            if not isinstance(codec_max_bitrate_factor, (float, int)):
                raise TypeError("Invalid type for `codec_max_bitrate_factor`, type has to be `float`")

        self._codec_max_bitrate_factor = codec_max_bitrate_factor

    @property
    def codec_bufsize_factor(self):
        # type: () -> float
        """Gets the codec_bufsize_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the bufsize of the codec configuration for the generated representations as a multiple of the targetBitrate

        :return: The codec_bufsize_factor of this H265PerTitleConfiguration.
        :rtype: float
        """
        return self._codec_bufsize_factor

    @codec_bufsize_factor.setter
    def codec_bufsize_factor(self, codec_bufsize_factor):
        # type: (float) -> None
        """Sets the codec_bufsize_factor of this H265PerTitleConfiguration.

        This factor is used to calculate the bufsize of the codec configuration for the generated representations as a multiple of the targetBitrate

        :param codec_bufsize_factor: The codec_bufsize_factor of this H265PerTitleConfiguration.
        :type: float
        """

        if codec_bufsize_factor is not None:
            if not isinstance(codec_bufsize_factor, (float, int)):
                raise TypeError("Invalid type for `codec_bufsize_factor`, type has to be `float`")

        self._codec_bufsize_factor = codec_bufsize_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(H265PerTitleConfiguration, self), "to_dict"):
            result = super(H265PerTitleConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, H265PerTitleConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.live_statistics_api import LiveStatisticsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.events.events_api import EventsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_api import SrtApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingVodJobInputType(Enum):
    VIDEO = "VIDEO"
    AUDIO = "AUDIO"
    SUBTITLES = "SUBTITLES"
    CLOSED_CAPTIONS = "CLOSED_CAPTIONS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Trimming(object):
    @poscheck_model
    def __init__(self,
                 offset=None,
                 duration=None,
                 ignore_duration_if_input_too_short=None,
                 start_pic_timing=None,
                 end_pic_timing=None):
        # type: (float, float, bool, string_types, string_types) -> None

        self._offset = None
        self._duration = None
        self._ignore_duration_if_input_too_short = None
        self._start_pic_timing = None
        self._end_pic_timing = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if duration is not None:
            self.duration = duration
        if ignore_duration_if_input_too_short is not None:
            self.ignore_duration_if_input_too_short = ignore_duration_if_input_too_short
        if start_pic_timing is not None:
            self.start_pic_timing = start_pic_timing
        if end_pic_timing is not None:
            self.end_pic_timing = end_pic_timing

    @property
    def openapi_types(self):
        types = {
            'offset': 'float',
            'duration': 'float',
            'ignore_duration_if_input_too_short': 'bool',
            'start_pic_timing': 'string_types',
            'end_pic_timing': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'duration': 'duration',
            'ignore_duration_if_input_too_short': 'ignoreDurationIfInputTooShort',
            'start_pic_timing': 'startPicTiming',
            'end_pic_timing': 'endPicTiming'
        }
        return attributes

    @property
    def offset(self):
        # type: () -> float
        """Gets the offset of this Trimming.

        Defines the offset in seconds from which the encoding should start, beginning at 0.

        :return: The offset of this Trimming.
        :rtype: float
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (float) -> None
        """Sets the offset of this Trimming.

        Defines the offset in seconds from which the encoding should start, beginning at 0.

        :param offset: The offset of this Trimming.
        :type: float
        """

        if offset is not None:
            if offset is not None and offset < 0:
                raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")
            if not isinstance(offset, (float, int)):
                raise TypeError("Invalid type for `offset`, type has to be `float`")

        self._offset = offset

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this Trimming.

        Defines how many seconds from the input will be encoded. If not set, the input will be encoded until its end.

        :return: The duration of this Trimming.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this Trimming.

        Defines how many seconds from the input will be encoded. If not set, the input will be encoded until its end.

        :param duration: The duration of this Trimming.
        :type: float
        """

        if duration is not None:
            if duration is not None and duration <= 0:
                raise ValueError("Invalid value for `duration`, must be a value greater than `0`")
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def ignore_duration_if_input_too_short(self):
        # type: () -> bool
        """Gets the ignore_duration_if_input_too_short of this Trimming.

        When true, \"duration\" will be interpreted as a maximum and not cause an error if the input is too short

        :return: The ignore_duration_if_input_too_short of this Trimming.
        :rtype: bool
        """
        return self._ignore_duration_if_input_too_short

    @ignore_duration_if_input_too_short.setter
    def ignore_duration_if_input_too_short(self, ignore_duration_if_input_too_short):
        # type: (bool) -> None
        """Sets the ignore_duration_if_input_too_short of this Trimming.

        When true, \"duration\" will be interpreted as a maximum and not cause an error if the input is too short

        :param ignore_duration_if_input_too_short: The ignore_duration_if_input_too_short of this Trimming.
        :type: bool
        """

        if ignore_duration_if_input_too_short is not None:
            if not isinstance(ignore_duration_if_input_too_short, bool):
                raise TypeError("Invalid type for `ignore_duration_if_input_too_short`, type has to be `bool`")

        self._ignore_duration_if_input_too_short = ignore_duration_if_input_too_short

    @property
    def start_pic_timing(self):
        # type: () -> string_types
        """Gets the start_pic_timing of this Trimming.

        Defines the H264 picture timing of the first frame from which the encoding should start. Any defined offset or duration in seconds will be ignored.

        :return: The start_pic_timing of this Trimming.
        :rtype: string_types
        """
        return self._start_pic_timing

    @start_pic_timing.setter
    def start_pic_timing(self, start_pic_timing):
        # type: (string_types) -> None
        """Sets the start_pic_timing of this Trimming.

        Defines the H264 picture timing of the first frame from which the encoding should start. Any defined offset or duration in seconds will be ignored.

        :param start_pic_timing: The start_pic_timing of this Trimming.
        :type: string_types
        """

        if start_pic_timing is not None:
            if not isinstance(start_pic_timing, string_types):
                raise TypeError("Invalid type for `start_pic_timing`, type has to be `string_types`")

        self._start_pic_timing = start_pic_timing

    @property
    def end_pic_timing(self):
        # type: () -> string_types
        """Gets the end_pic_timing of this Trimming.

        Defines the H264 picture timing of the last frame, that will be included in the encoding. Any defined offset or duration in seconds will be ignored.

        :return: The end_pic_timing of this Trimming.
        :rtype: string_types
        """
        return self._end_pic_timing

    @end_pic_timing.setter
    def end_pic_timing(self, end_pic_timing):
        # type: (string_types) -> None
        """Sets the end_pic_timing of this Trimming.

        Defines the H264 picture timing of the last frame, that will be included in the encoding. Any defined offset or duration in seconds will be ignored.

        :param end_pic_timing: The end_pic_timing of this Trimming.
        :type: string_types
        """

        if end_pic_timing is not None:
            if not isinstance(end_pic_timing, string_types):
                raise TypeError("Invalid type for `end_pic_timing`, type has to be `string_types`")

        self._end_pic_timing = end_pic_timing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Trimming):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.inputs.azure.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.azure.azure_input_list_query_params import AzureInputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.finished.finished_api import FinishedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.transfer_error_api import TransferErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.encoding_status_changed.encoding_status_changed_api import EncodingStatusChangedApi


class EncodingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.finished = FinishedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.error = ErrorApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.transfer_error = TransferErrorApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.live_input_stream_changed = LiveInputStreamChangedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.encoding_status_changed = EncodingStatusChangedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ManifestGenerator(Enum):
    LEGACY = "LEGACY"
    V2 = "V2"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.sftp_input import SftpInput
from bitmovin_api_sdk.encoding.inputs.sftp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.sftp.sftp_input_list_query_params import SftpInputListQueryParams


class SftpApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SftpApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, sftp_input, **kwargs):
        # type: (SftpInput, dict) -> SftpInput
        """Create SFTP Input

        :param sftp_input: The SFTP input to be created
        :type sftp_input: SftpInput, required
        :return: SFTP input
        :rtype: SftpInput
        """

        return self.api_client.post(
            '/encoding/inputs/sftp',
            sftp_input,
            type=SftpInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> SftpInput
        """Delete SFTP Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: SftpInput
        """

        return self.api_client.delete(
            '/encoding/inputs/sftp/{input_id}',
            path_params={'input_id': input_id},
            type=SftpInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> SftpInput
        """SFTP Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: SFTP input
        :rtype: SftpInput
        """

        return self.api_client.get(
            '/encoding/inputs/sftp/{input_id}',
            path_params={'input_id': input_id},
            type=SftpInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (SftpInputListQueryParams, dict) -> SftpInput
        """List SFTP Inputs

        :param query_params: Query parameters
        :type query_params: SftpInputListQueryParams
        :return: List of SFTP inputs
        :rtype: SftpInput
        """

        return self.api_client.get(
            '/encoding/inputs/sftp',
            query_params=query_params,
            pagination_response=True,
            type=SftpInput,
            **kwargs
        )



from bitmovin_api_sdk.account.organizations.groups.invitations.invitations_api import InvitationsApi
from bitmovin_api_sdk.account.organizations.groups.invitations.invitation_list_query_params import InvitationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamsLiveLifeCycle(Enum):
    PROVISIONING = "PROVISIONING"
    STOPPED = "STOPPED"
    RUNNING = "RUNNING"
    ERROR = "ERROR"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SimpleEncodingVodJobErrors(object):
    @poscheck_model
    def __init__(self,
                 error_code=None,
                 message=None,
                 details=None):
        # type: (string_types, string_types, string_types) -> None

        self._error_code = None
        self._message = None
        self._details = None
        self.discriminator = None

        if error_code is not None:
            self.error_code = error_code
        if message is not None:
            self.message = message
        if details is not None:
            self.details = details

    @property
    def openapi_types(self):
        types = {
            'error_code': 'string_types',
            'message': 'string_types',
            'details': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'error_code': 'errorCode',
            'message': 'message',
            'details': 'details'
        }
        return attributes

    @property
    def error_code(self):
        # type: () -> string_types
        """Gets the error_code of this SimpleEncodingVodJobErrors.

        Stable code that identifies the error type.

        :return: The error_code of this SimpleEncodingVodJobErrors.
        :rtype: string_types
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        # type: (string_types) -> None
        """Sets the error_code of this SimpleEncodingVodJobErrors.

        Stable code that identifies the error type.

        :param error_code: The error_code of this SimpleEncodingVodJobErrors.
        :type: string_types
        """

        if error_code is not None:
            if not isinstance(error_code, string_types):
                raise TypeError("Invalid type for `error_code`, type has to be `string_types`")

        self._error_code = error_code

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this SimpleEncodingVodJobErrors.

        Human readable description of the error.

        :return: The message of this SimpleEncodingVodJobErrors.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this SimpleEncodingVodJobErrors.

        Human readable description of the error.

        :param message: The message of this SimpleEncodingVodJobErrors.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def details(self):
        # type: () -> string_types
        """Gets the details of this SimpleEncodingVodJobErrors.

        Additional details of the error if available.

        :return: The details of this SimpleEncodingVodJobErrors.
        :rtype: string_types
        """
        return self._details

    @details.setter
    def details(self, details):
        # type: (string_types) -> None
        """Sets the details of this SimpleEncodingVodJobErrors.

        Additional details of the error if available.

        :param details: The details of this SimpleEncodingVodJobErrors.
        :type: string_types
        """

        if details is not None:
            if not isinstance(details, string_types):
                raise TypeError("Invalid type for `details`, type has to be `string_types`")

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobErrors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.emails.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.notifications.emails.encoding.email_notification_list_query_params import EmailNotificationListQueryParams



from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.scc.scc_api import SccApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.scc.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.scc.scc_caption_list_query_params import SccCaptionListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ac3_channel_layout import Ac3ChannelLayout
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
import pprint
import six


class Eac3AudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 channel_layout=None,
                 cutoff_frequency=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, Ac3ChannelLayout, int) -> None
        super(Eac3AudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._channel_layout = None
        self._cutoff_frequency = None
        self.discriminator = None

        if channel_layout is not None:
            self.channel_layout = channel_layout
        if cutoff_frequency is not None:
            self.cutoff_frequency = cutoff_frequency

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Eac3AudioConfiguration, self), 'openapi_types'):
            types = getattr(super(Eac3AudioConfiguration, self), 'openapi_types')

        types.update({
            'channel_layout': 'Ac3ChannelLayout',
            'cutoff_frequency': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Eac3AudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Eac3AudioConfiguration, self), 'attribute_map')

        attributes.update({
            'channel_layout': 'channelLayout',
            'cutoff_frequency': 'cutoffFrequency'
        })
        return attributes

    @property
    def channel_layout(self):
        # type: () -> Ac3ChannelLayout
        """Gets the channel_layout of this Eac3AudioConfiguration.

        Channel layout of the audio codec configuration

        :return: The channel_layout of this Eac3AudioConfiguration.
        :rtype: Ac3ChannelLayout
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        # type: (Ac3ChannelLayout) -> None
        """Sets the channel_layout of this Eac3AudioConfiguration.

        Channel layout of the audio codec configuration

        :param channel_layout: The channel_layout of this Eac3AudioConfiguration.
        :type: Ac3ChannelLayout
        """

        if channel_layout is not None:
            if not isinstance(channel_layout, Ac3ChannelLayout):
                raise TypeError("Invalid type for `channel_layout`, type has to be `Ac3ChannelLayout`")

        self._channel_layout = channel_layout

    @property
    def cutoff_frequency(self):
        # type: () -> int
        """Gets the cutoff_frequency of this Eac3AudioConfiguration.

        The highest frequency that will pass the audio encoder. This value is optional.

        :return: The cutoff_frequency of this Eac3AudioConfiguration.
        :rtype: int
        """
        return self._cutoff_frequency

    @cutoff_frequency.setter
    def cutoff_frequency(self, cutoff_frequency):
        # type: (int) -> None
        """Sets the cutoff_frequency of this Eac3AudioConfiguration.

        The highest frequency that will pass the audio encoder. This value is optional.

        :param cutoff_frequency: The cutoff_frequency of this Eac3AudioConfiguration.
        :type: int
        """

        if cutoff_frequency is not None:
            if not isinstance(cutoff_frequency, int):
                raise TypeError("Invalid type for `cutoff_frequency`, type has to be `int`")

        self._cutoff_frequency = cutoff_frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Eac3AudioConfiguration, self), "to_dict"):
            result = super(Eac3AudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Eac3AudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.streams.streams_api import StreamsApi
from bitmovin_api_sdk.streams.search.search_api import SearchApi
from bitmovin_api_sdk.streams.video.video_api import VideoApi
from bitmovin_api_sdk.streams.live.live_api import LiveApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.s3_role_based_input import S3RoleBasedInput
from bitmovin_api_sdk.encoding.inputs.s3_role_based.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.s3_role_based.s3_role_based_input_list_query_params import S3RoleBasedInputListQueryParams


class S3RoleBasedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(S3RoleBasedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, s3_role_based_input, **kwargs):
        # type: (S3RoleBasedInput, dict) -> S3RoleBasedInput
        """Create S3 Role-based Input

        :param s3_role_based_input: The S3 Role-based input to be created  The following permissions are required for S3 Role-based input:   * s3:GetObject   * s3:GetBucketLocation, 
        :type s3_role_based_input: S3RoleBasedInput, required
        :return: S3 Role-based Input
        :rtype: S3RoleBasedInput
        """

        return self.api_client.post(
            '/encoding/inputs/s3-role-based',
            s3_role_based_input,
            type=S3RoleBasedInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> S3RoleBasedInput
        """Delete S3 Role-based Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: S3RoleBasedInput
        """

        return self.api_client.delete(
            '/encoding/inputs/s3-role-based/{input_id}',
            path_params={'input_id': input_id},
            type=S3RoleBasedInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> S3RoleBasedInput
        """S3 Role-based Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: S3 Role-based Input
        :rtype: S3RoleBasedInput
        """

        return self.api_client.get(
            '/encoding/inputs/s3-role-based/{input_id}',
            path_params={'input_id': input_id},
            type=S3RoleBasedInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (S3RoleBasedInputListQueryParams, dict) -> S3RoleBasedInput
        """List S3 Role-based Inputs

        :param query_params: Query parameters
        :type query_params: S3RoleBasedInputListQueryParams
        :return: List of S3 Role-based Inputs
        :rtype: S3RoleBasedInput
        """

        return self.api_client.get(
            '/encoding/inputs/s3-role-based',
            query_params=query_params,
            pagination_response=True,
            type=S3RoleBasedInput,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.vtt.dash_vtt_representation_list_query_params import DashVttRepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyAtmosInputFormat(Enum):
    DAMF = "DAMF"
    ADM = "ADM"



from bitmovin_api_sdk.encoding.configurations.audio.eac3.eac3_api import Eac3Api
from bitmovin_api_sdk.encoding.configurations.audio.eac3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.eac3.eac3_audio_configuration_list_query_params import Eac3AudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.scaling_algorithm import ScalingAlgorithm
import pprint
import six


class ScaleFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 scaling_algorithm=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, ScalingAlgorithm, int, int) -> None
        super(ScaleFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._width = None
        self._height = None
        self._scaling_algorithm = None
        self._sample_aspect_ratio_numerator = None
        self._sample_aspect_ratio_denominator = None
        self.discriminator = None

        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if scaling_algorithm is not None:
            self.scaling_algorithm = scaling_algorithm
        if sample_aspect_ratio_numerator is not None:
            self.sample_aspect_ratio_numerator = sample_aspect_ratio_numerator
        if sample_aspect_ratio_denominator is not None:
            self.sample_aspect_ratio_denominator = sample_aspect_ratio_denominator

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ScaleFilter, self), 'openapi_types'):
            types = getattr(super(ScaleFilter, self), 'openapi_types')

        types.update({
            'width': 'int',
            'height': 'int',
            'scaling_algorithm': 'ScalingAlgorithm',
            'sample_aspect_ratio_numerator': 'int',
            'sample_aspect_ratio_denominator': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ScaleFilter, self), 'attribute_map'):
            attributes = getattr(super(ScaleFilter, self), 'attribute_map')

        attributes.update({
            'width': 'width',
            'height': 'height',
            'scaling_algorithm': 'scalingAlgorithm',
            'sample_aspect_ratio_numerator': 'sampleAspectRatioNumerator',
            'sample_aspect_ratio_denominator': 'sampleAspectRatioDenominator'
        })
        return attributes

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this ScaleFilter.

        The width of the output frame in pixels. If not set it will be based on the configured height by maintaining the original aspect ratio. If height is also not set, the original source dimensions will be applied.

        :return: The width of this ScaleFilter.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this ScaleFilter.

        The width of the output frame in pixels. If not set it will be based on the configured height by maintaining the original aspect ratio. If height is also not set, the original source dimensions will be applied.

        :param width: The width of this ScaleFilter.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this ScaleFilter.

        The height of the output frame in pixels. If not set it will be based on the configured width by maintaining the original aspect ratio. If width is also not set, the original source dimensions will be applied.

        :return: The height of this ScaleFilter.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this ScaleFilter.

        The height of the output frame in pixels. If not set it will be based on the configured width by maintaining the original aspect ratio. If width is also not set, the original source dimensions will be applied.

        :param height: The height of this ScaleFilter.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def scaling_algorithm(self):
        # type: () -> ScalingAlgorithm
        """Gets the scaling_algorithm of this ScaleFilter.


        :return: The scaling_algorithm of this ScaleFilter.
        :rtype: ScalingAlgorithm
        """
        return self._scaling_algorithm

    @scaling_algorithm.setter
    def scaling_algorithm(self, scaling_algorithm):
        # type: (ScalingAlgorithm) -> None
        """Sets the scaling_algorithm of this ScaleFilter.


        :param scaling_algorithm: The scaling_algorithm of this ScaleFilter.
        :type: ScalingAlgorithm
        """

        if scaling_algorithm is not None:
            if not isinstance(scaling_algorithm, ScalingAlgorithm):
                raise TypeError("Invalid type for `scaling_algorithm`, type has to be `ScalingAlgorithm`")

        self._scaling_algorithm = scaling_algorithm

    @property
    def sample_aspect_ratio_numerator(self):
        # type: () -> int
        """Gets the sample_aspect_ratio_numerator of this ScaleFilter.

        The numerator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioDenominator is set.

        :return: The sample_aspect_ratio_numerator of this ScaleFilter.
        :rtype: int
        """
        return self._sample_aspect_ratio_numerator

    @sample_aspect_ratio_numerator.setter
    def sample_aspect_ratio_numerator(self, sample_aspect_ratio_numerator):
        # type: (int) -> None
        """Sets the sample_aspect_ratio_numerator of this ScaleFilter.

        The numerator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioDenominator is set.

        :param sample_aspect_ratio_numerator: The sample_aspect_ratio_numerator of this ScaleFilter.
        :type: int
        """

        if sample_aspect_ratio_numerator is not None:
            if not isinstance(sample_aspect_ratio_numerator, int):
                raise TypeError("Invalid type for `sample_aspect_ratio_numerator`, type has to be `int`")

        self._sample_aspect_ratio_numerator = sample_aspect_ratio_numerator

    @property
    def sample_aspect_ratio_denominator(self):
        # type: () -> int
        """Gets the sample_aspect_ratio_denominator of this ScaleFilter.

        The denominator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioNumerator is set.

        :return: The sample_aspect_ratio_denominator of this ScaleFilter.
        :rtype: int
        """
        return self._sample_aspect_ratio_denominator

    @sample_aspect_ratio_denominator.setter
    def sample_aspect_ratio_denominator(self, sample_aspect_ratio_denominator):
        # type: (int) -> None
        """Sets the sample_aspect_ratio_denominator of this ScaleFilter.

        The denominator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioNumerator is set.

        :param sample_aspect_ratio_denominator: The sample_aspect_ratio_denominator of this ScaleFilter.
        :type: int
        """

        if sample_aspect_ratio_denominator is not None:
            if not isinstance(sample_aspect_ratio_denominator, int):
                raise TypeError("Invalid type for `sample_aspect_ratio_denominator`, type has to be `int`")

        self._sample_aspect_ratio_denominator = sample_aspect_ratio_denominator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ScaleFilter, self), "to_dict"):
            result = super(ScaleFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScaleFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding import Encoding
from bitmovin_api_sdk.models.live_encoding import LiveEncoding
from bitmovin_api_sdk.models.start_encoding_request import StartEncodingRequest
from bitmovin_api_sdk.models.start_live_encoding_request import StartLiveEncodingRequest
from bitmovin_api_sdk.models.task import Task
import pprint
import six


class HistoryEncoding(object):
    @poscheck_model
    def __init__(self,
                 encoding=None,
                 live=None,
                 vod_start_reqeust=None,
                 live_start_reqeust=None,
                 status=None,
                 input_streams=None,
                 streams=None,
                 muxings=None,
                 key_frames=None,
                 sidecar_files=None,
                 transfer_retries=None,
                 convert_scc_captions=None):
        # type: (Encoding, LiveEncoding, StartEncodingRequest, StartLiveEncodingRequest, Task, list[StreamInput], list[HistoryStream], list[HistoryMuxing], list[Keyframe], list[SidecarFile], list[TransferRetry], list[ConvertSccCaption]) -> None

        self._encoding = None
        self._live = None
        self._vod_start_reqeust = None
        self._live_start_reqeust = None
        self._status = None
        self._input_streams = list()
        self._streams = list()
        self._muxings = list()
        self._key_frames = list()
        self._sidecar_files = list()
        self._transfer_retries = list()
        self._convert_scc_captions = list()
        self.discriminator = None

        if encoding is not None:
            self.encoding = encoding
        if live is not None:
            self.live = live
        if vod_start_reqeust is not None:
            self.vod_start_reqeust = vod_start_reqeust
        if live_start_reqeust is not None:
            self.live_start_reqeust = live_start_reqeust
        if status is not None:
            self.status = status
        if input_streams is not None:
            self.input_streams = input_streams
        if streams is not None:
            self.streams = streams
        if muxings is not None:
            self.muxings = muxings
        if key_frames is not None:
            self.key_frames = key_frames
        if sidecar_files is not None:
            self.sidecar_files = sidecar_files
        if transfer_retries is not None:
            self.transfer_retries = transfer_retries
        if convert_scc_captions is not None:
            self.convert_scc_captions = convert_scc_captions

    @property
    def openapi_types(self):
        types = {
            'encoding': 'Encoding',
            'live': 'LiveEncoding',
            'vod_start_reqeust': 'StartEncodingRequest',
            'live_start_reqeust': 'StartLiveEncodingRequest',
            'status': 'Task',
            'input_streams': 'list[StreamInput]',
            'streams': 'list[HistoryStream]',
            'muxings': 'list[HistoryMuxing]',
            'key_frames': 'list[Keyframe]',
            'sidecar_files': 'list[SidecarFile]',
            'transfer_retries': 'list[TransferRetry]',
            'convert_scc_captions': 'list[ConvertSccCaption]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'encoding': 'encoding',
            'live': 'live',
            'vod_start_reqeust': 'vodStartReqeust',
            'live_start_reqeust': 'liveStartReqeust',
            'status': 'status',
            'input_streams': 'inputStreams',
            'streams': 'streams',
            'muxings': 'muxings',
            'key_frames': 'keyFrames',
            'sidecar_files': 'sidecarFiles',
            'transfer_retries': 'transferRetries',
            'convert_scc_captions': 'convertSccCaptions'
        }
        return attributes

    @property
    def encoding(self):
        # type: () -> Encoding
        """Gets the encoding of this HistoryEncoding.

        Encoding

        :return: The encoding of this HistoryEncoding.
        :rtype: Encoding
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        # type: (Encoding) -> None
        """Sets the encoding of this HistoryEncoding.

        Encoding

        :param encoding: The encoding of this HistoryEncoding.
        :type: Encoding
        """

        if encoding is not None:
            if not isinstance(encoding, Encoding):
                raise TypeError("Invalid type for `encoding`, type has to be `Encoding`")

        self._encoding = encoding

    @property
    def live(self):
        # type: () -> LiveEncoding
        """Gets the live of this HistoryEncoding.

        Live Details

        :return: The live of this HistoryEncoding.
        :rtype: LiveEncoding
        """
        return self._live

    @live.setter
    def live(self, live):
        # type: (LiveEncoding) -> None
        """Sets the live of this HistoryEncoding.

        Live Details

        :param live: The live of this HistoryEncoding.
        :type: LiveEncoding
        """

        if live is not None:
            if not isinstance(live, LiveEncoding):
                raise TypeError("Invalid type for `live`, type has to be `LiveEncoding`")

        self._live = live

    @property
    def vod_start_reqeust(self):
        # type: () -> StartEncodingRequest
        """Gets the vod_start_reqeust of this HistoryEncoding.

        VOD Encoding Start Request

        :return: The vod_start_reqeust of this HistoryEncoding.
        :rtype: StartEncodingRequest
        """
        return self._vod_start_reqeust

    @vod_start_reqeust.setter
    def vod_start_reqeust(self, vod_start_reqeust):
        # type: (StartEncodingRequest) -> None
        """Sets the vod_start_reqeust of this HistoryEncoding.

        VOD Encoding Start Request

        :param vod_start_reqeust: The vod_start_reqeust of this HistoryEncoding.
        :type: StartEncodingRequest
        """

        if vod_start_reqeust is not None:
            if not isinstance(vod_start_reqeust, StartEncodingRequest):
                raise TypeError("Invalid type for `vod_start_reqeust`, type has to be `StartEncodingRequest`")

        self._vod_start_reqeust = vod_start_reqeust

    @property
    def live_start_reqeust(self):
        # type: () -> StartLiveEncodingRequest
        """Gets the live_start_reqeust of this HistoryEncoding.

        Live Encoding Start Request

        :return: The live_start_reqeust of this HistoryEncoding.
        :rtype: StartLiveEncodingRequest
        """
        return self._live_start_reqeust

    @live_start_reqeust.setter
    def live_start_reqeust(self, live_start_reqeust):
        # type: (StartLiveEncodingRequest) -> None
        """Sets the live_start_reqeust of this HistoryEncoding.

        Live Encoding Start Request

        :param live_start_reqeust: The live_start_reqeust of this HistoryEncoding.
        :type: StartLiveEncodingRequest
        """

        if live_start_reqeust is not None:
            if not isinstance(live_start_reqeust, StartLiveEncodingRequest):
                raise TypeError("Invalid type for `live_start_reqeust`, type has to be `StartLiveEncodingRequest`")

        self._live_start_reqeust = live_start_reqeust

    @property
    def status(self):
        # type: () -> Task
        """Gets the status of this HistoryEncoding.

        Encoding Status

        :return: The status of this HistoryEncoding.
        :rtype: Task
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Task) -> None
        """Sets the status of this HistoryEncoding.

        Encoding Status

        :param status: The status of this HistoryEncoding.
        :type: Task
        """

        if status is not None:
            if not isinstance(status, Task):
                raise TypeError("Invalid type for `status`, type has to be `Task`")

        self._status = status

    @property
    def input_streams(self):
        # type: () -> list[StreamInput]
        """Gets the input_streams of this HistoryEncoding.


        :return: The input_streams of this HistoryEncoding.
        :rtype: list[StreamInput]
        """
        return self._input_streams

    @input_streams.setter
    def input_streams(self, input_streams):
        # type: (list) -> None
        """Sets the input_streams of this HistoryEncoding.


        :param input_streams: The input_streams of this HistoryEncoding.
        :type: list[StreamInput]
        """

        if input_streams is not None:
            if not isinstance(input_streams, list):
                raise TypeError("Invalid type for `input_streams`, type has to be `list[StreamInput]`")

        self._input_streams = input_streams

    @property
    def streams(self):
        # type: () -> list[HistoryStream]
        """Gets the streams of this HistoryEncoding.


        :return: The streams of this HistoryEncoding.
        :rtype: list[HistoryStream]
        """
        return self._streams

    @streams.setter
    def streams(self, streams):
        # type: (list) -> None
        """Sets the streams of this HistoryEncoding.


        :param streams: The streams of this HistoryEncoding.
        :type: list[HistoryStream]
        """

        if streams is not None:
            if not isinstance(streams, list):
                raise TypeError("Invalid type for `streams`, type has to be `list[HistoryStream]`")

        self._streams = streams

    @property
    def muxings(self):
        # type: () -> list[HistoryMuxing]
        """Gets the muxings of this HistoryEncoding.


        :return: The muxings of this HistoryEncoding.
        :rtype: list[HistoryMuxing]
        """
        return self._muxings

    @muxings.setter
    def muxings(self, muxings):
        # type: (list) -> None
        """Sets the muxings of this HistoryEncoding.


        :param muxings: The muxings of this HistoryEncoding.
        :type: list[HistoryMuxing]
        """

        if muxings is not None:
            if not isinstance(muxings, list):
                raise TypeError("Invalid type for `muxings`, type has to be `list[HistoryMuxing]`")

        self._muxings = muxings

    @property
    def key_frames(self):
        # type: () -> list[Keyframe]
        """Gets the key_frames of this HistoryEncoding.


        :return: The key_frames of this HistoryEncoding.
        :rtype: list[Keyframe]
        """
        return self._key_frames

    @key_frames.setter
    def key_frames(self, key_frames):
        # type: (list) -> None
        """Sets the key_frames of this HistoryEncoding.


        :param key_frames: The key_frames of this HistoryEncoding.
        :type: list[Keyframe]
        """

        if key_frames is not None:
            if not isinstance(key_frames, list):
                raise TypeError("Invalid type for `key_frames`, type has to be `list[Keyframe]`")

        self._key_frames = key_frames

    @property
    def sidecar_files(self):
        # type: () -> list[SidecarFile]
        """Gets the sidecar_files of this HistoryEncoding.


        :return: The sidecar_files of this HistoryEncoding.
        :rtype: list[SidecarFile]
        """
        return self._sidecar_files

    @sidecar_files.setter
    def sidecar_files(self, sidecar_files):
        # type: (list) -> None
        """Sets the sidecar_files of this HistoryEncoding.


        :param sidecar_files: The sidecar_files of this HistoryEncoding.
        :type: list[SidecarFile]
        """

        if sidecar_files is not None:
            if not isinstance(sidecar_files, list):
                raise TypeError("Invalid type for `sidecar_files`, type has to be `list[SidecarFile]`")

        self._sidecar_files = sidecar_files

    @property
    def transfer_retries(self):
        # type: () -> list[TransferRetry]
        """Gets the transfer_retries of this HistoryEncoding.


        :return: The transfer_retries of this HistoryEncoding.
        :rtype: list[TransferRetry]
        """
        return self._transfer_retries

    @transfer_retries.setter
    def transfer_retries(self, transfer_retries):
        # type: (list) -> None
        """Sets the transfer_retries of this HistoryEncoding.


        :param transfer_retries: The transfer_retries of this HistoryEncoding.
        :type: list[TransferRetry]
        """

        if transfer_retries is not None:
            if not isinstance(transfer_retries, list):
                raise TypeError("Invalid type for `transfer_retries`, type has to be `list[TransferRetry]`")

        self._transfer_retries = transfer_retries

    @property
    def convert_scc_captions(self):
        # type: () -> list[ConvertSccCaption]
        """Gets the convert_scc_captions of this HistoryEncoding.


        :return: The convert_scc_captions of this HistoryEncoding.
        :rtype: list[ConvertSccCaption]
        """
        return self._convert_scc_captions

    @convert_scc_captions.setter
    def convert_scc_captions(self, convert_scc_captions):
        # type: (list) -> None
        """Sets the convert_scc_captions of this HistoryEncoding.


        :param convert_scc_captions: The convert_scc_captions of this HistoryEncoding.
        :type: list[ConvertSccCaption]
        """

        if convert_scc_captions is not None:
            if not isinstance(convert_scc_captions, list):
                raise TypeError("Invalid type for `convert_scc_captions`, type has to be `list[ConvertSccCaption]`")

        self._convert_scc_captions = convert_scc_captions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoryEncoding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.encoding import Encoding
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.history_encoding import HistoryEncoding
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.history.encodings.encoding_list_query_params import EncodingListQueryParams


class EncodingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> HistoryEncoding
        """(Experimental) History Encoding Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: History Encoding
        :rtype: HistoryEncoding
        """

        return self.api_client.get(
            '/encoding/history/encodings/{encoding_id}',
            path_params={'encoding_id': encoding_id},
            type=HistoryEncoding,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (EncodingListQueryParams, dict) -> Encoding
        """(Experimental) List all History Encodings

        :param query_params: Query parameters
        :type query_params: EncodingListQueryParams
        :return: List of encodings
        :rtype: Encoding
        """

        return self.api_client.get(
            '/encoding/history/encodings',
            query_params=query_params,
            pagination_response=True,
            type=Encoding,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.static_ip import StaticIp
from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ip_list_query_params import StaticIpListQueryParams


class StaticIpsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StaticIpsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, static_ip, **kwargs):
        # type: (StaticIp, dict) -> StaticIp
        """Add Static IP Address

        :param static_ip: The static ip to be created
        :type static_ip: StaticIp, required
        :return: Static IP Address
        :rtype: StaticIp
        """

        return self.api_client.post(
            '/encoding/infrastructure/static-ips',
            static_ip,
            type=StaticIp,
            **kwargs
        )

    def delete(self, id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Static IP Address

        :param id: Id of the Static IP Address
        :type id: string_types, required
        :return: Id of the Static IP Address
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/infrastructure/static-ips/{id}',
            path_params={'id': id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, id, **kwargs):
        # type: (string_types, dict) -> StaticIp
        """Static IP Address Details

        :param id: Id of the Static IP Address
        :type id: string_types, required
        :return: Static IP Address
        :rtype: StaticIp
        """

        return self.api_client.get(
            '/encoding/infrastructure/static-ips/{id}',
            path_params={'id': id},
            type=StaticIp,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (StaticIpListQueryParams, dict) -> StaticIp
        """List all Static IP Addresses

        :param query_params: Query parameters
        :type query_params: StaticIpListQueryParams
        :return: All Static IP Addresses.
        :rtype: StaticIp
        """

        return self.api_client.get(
            '/encoding/infrastructure/static-ips',
            query_params=query_params,
            pagination_response=True,
            type=StaticIp,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AdaptiveQuantMode(Enum):
    DISABLED = "DISABLED"
    VARIANCE = "VARIANCE"
    AUTO_VARIANCE = "AUTO_VARIANCE"
    AUTO_VARIANCE_DARK_SCENES = "AUTO_VARIANCE_DARK_SCENES"
